
# Example script for the integration of GAALOPWeb in Python
# Written by Christian Steinmetz.
# Version 1.0, 16.04.2020

from gaalopscript2Python import gaalopscriptFile2Python, gaalopscriptString2Python

recompile = True # Should the script be compiled with GAALOPWeb (may take a while)? Must be True at first time and after a change in GAALOPScript .

if recompile:
    direct = False # Compile script directly from string or from file?
    if direct:
        gaalopscriptString2Python("""    
            //creating the CGA points;
            x1=createPoint(a1,a2,a3); 
            x2=createPoint(b1,b2,b3);
            x3=createPoint(c1,c2,c3);

            // creating the spheres;

            ?S1=x1-0.5*(d14*d14)*einf;
            ?S2=x2-0.5*(d24*d24)*einf;
            ?S3=x3-0.5*(d34*d34)*einf;

            // The PointPair in the intersection;

            ?PP4=S1^S2^S3;
            ?DualPP4=*PP4;

            // Extraction of the two points;

            ?x4a=-(-sqrt(DualPP4.DualPP4)+DualPP4)/(einf.DualPP4);
            ?x4b=-(sqrt(DualPP4.DualPP4)+DualPP4)/(einf.DualPP4);
        """
        , "threeSpheres")
    else:
        gaalopscriptFile2Python("threeSpheres.clu")

# Import generated python file
from threeSpheres import threespheres

# Assign some values for the three spheres example
a1=0
a2=0
a3=0
b1=0
b2=0.4
b3=0
c1=0
c2=0.45
c3=0.2
d14=0.5
d24=0.4
d34=0.3

# Compute the solution with calling three spheres
[DualPP4, PP4, S1, S2, S3, x4a, x4b] = threespheres(a1, a2, a3, b1, b2, b3, c1, c2, c3, d14, d24, d34)

# Print results
print("The two points are:")
print(x4a[1:4]) # Print components e1, e2, e3
print(x4b[1:4]) # Print components e1, e2, e3